"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const PURE_ANNOTATION = "#__PURE__";
const isPureAnnotated = (comments) => {
    if (typeof comments === "undefined") {
        return false;
    }
    if (comments && comments.length > 0) {
        return comments[comments.length - 1].value === PURE_ANNOTATION;
    }
    return false;
};
const createComponentBlock = (value) => ({
    type: "CommentBlock",
    value,
});
const isVariableUsedInCallback = (nodePath) => {
    let used = false;
    const scope = nodePath.parentPath.scope;
    const traverseReferencedIdentifier = (nodePath) => nodePath.traverse({
        ReferencedIdentifier(n) {
            if (scope.hasOwnBinding(n.node.name)) {
                used = true;
            }
        },
    });
    nodePath.traverse({
        ArrowFunctionExpression: (nodePath) => {
            traverseReferencedIdentifier(nodePath);
        },
        FunctionExpression: (nodePath) => {
            traverseReferencedIdentifier(nodePath);
        },
    });
    return used;
};
const isPureCall = (nodePath) => {
    if (nodePath.parentPath.isAssignmentExpression()) {
        return true;
    }
    if (nodePath.parentPath.isVariableDeclarator()) {
        return !isVariableUsedInCallback(nodePath);
    }
    if (nodePath.parentPath.isCallExpression() &&
        (nodePath.parentPath.get("arguments") || []).indexOf(nodePath) > -1) {
        return true;
    }
    return false;
};
exports.default = () => ({
    name: "pure-calls-annotation",
    inherits: require("@babel/plugin-syntax-dynamic-import").default,
    visitor: {
        CallExpression: {
            enter(nodePath) {
                if (isPureCall(nodePath)) {
                    if (!isPureAnnotated(nodePath.node.leadingComments)) {
                        const pureAnnotation = createComponentBlock(PURE_ANNOTATION);
                        nodePath.replaceWith(Object.assign(Object.assign({}, nodePath.node), { leadingComments: nodePath.node.leadingComments
                                ? nodePath.node.leadingComments.concat(pureAnnotation)
                                : [pureAnnotation] }));
                    }
                }
            },
        },
    },
});
//# sourceMappingURL=index.js.map